@@ -24,7 +24,7 @@ pub type Result<T, E = Error> = std::result::Result<T, E>;
 #[derive(Debug, Error)]
 #[allow(missing_docs)]
 pub enum Error {
-    #[error("Only messages requiring auth accumultion should be sent via \"send_messages_to_all_nodes_or_directly_handle_for_accumulation\"")]
+    #[error("Only messages requiring auth accumulation should be sent via \"send_messages_to_all_nodes_or_directly_handle_for_accumulation\"")]
     SendOrHandlingNormalMsg,
     #[error("There was a problem during acquisition of a tokio::sync::semaphore permit.")]
     PermitAcquisitionFailed,
@@ -40,22 +40,14 @@ pub enum Error {
     EmptyRecipientList,
     #[error("Could not connect to any bootstrap contact")]
     BootstrapFailed,
-    #[error("Cannot connect to the endpoint: {err}")]
-    CannotConnectEndpoint {
-        #[from]
-        err: qp2p::EndpointError,
-    },
-    #[error("Address not reachable: {err}")]
-    AddressNotReachable {
-        #[from]
-        err: qp2p::RpcError,
-    },
+    #[error("Cannot connect to the endpoint: {0}")]
+    CannotConnectEndpoint(#[from] qp2p::EndpointError),
+    #[error("Address not reachable: {0}")]
+    AddressNotReachable(#[from] qp2p::RpcError),
     #[error("The node is not in a state to handle the action.")]
     InvalidState,
     #[error("Invalid source location")]
     InvalidSrcLocation,
-    #[error("Invalid destination location: {0}")]
-    InvalidDstLocation(String),
     #[error("Content of a received message is inconsistent.")]
     InvalidMessage,
     #[error("A signature share is invalid.")]
@@ -70,9 +62,9 @@ pub enum Error {
     InvalidSectionChain(#[from] SecuredLinkedListError),
     #[error("Messaging protocol error: {0}")]
     Messaging(#[from] crate::messaging::Error),
-    #[error("invalid payload")]
+    #[error("Invalid payload")]
     InvalidPayload,
-    #[error("Routing is set to not allow taking any new node")]
+    #[error("The section is currently set to not allow taking any new node")]
     TryJoinLater,
     #[error("No matching Section")]
     NoMatchingSection,
@@ -83,12 +75,12 @@ pub enum Error {
     /// Timeout when trying to join the network
     #[error("Timeout when trying to join the network")]
     JoinTimeout,
-    /// Logic error.
-    #[error("Logic error: {0}")]
-    Logic(String),
     /// Database error.
     #[error("Database error:: {0}")]
     Database(#[from] crate::dbs::Error),
+    /// Chunk Disk Store error.
+    #[error("Chunk Disk Store error:: {0}")]
+    ChunkDiskStore(#[from] crate::node::routing::ChunkStoreError),
     /// Not enough in the section to perform Chunk operation
     #[error("Not enough Adults available in Section({0:?}) to perform operation")]
     NoAdults(Prefix),
@@ -104,9 +96,6 @@ pub enum Error {
     /// Key, Value pair not found.
     #[error("No such data: {0:?}")]
     NoSuchData(DataAddress),
-    /// Creating temp directory failed.
-    #[error("Could not create temp store: {0}")]
-    TempDirCreationFailed(String),
     /// Chunk already exists for this node
     #[error("Data already exists at this node")]
     DataExists,
@@ -125,22 +114,13 @@ pub enum Error {
     /// Network data error.
     #[error("Network data error:: {0}")]
     NetworkData(#[from] crate::types::Error),
-    // /// Message is invalid.
-    // #[error("Message with id: '{0:?}' is invalid. {1}")]
-    // InvalidMessageReceived(MessageId, String),
     /// Data owner provided is invalid.
     #[error("Provided PublicKey is not a valid owner. Provided PublicKey: {0}")]
     InvalidOwner(PublicKey),
-    /// Operation is invalid, eg signing validation
-    #[error("Invalid operation: {0}")]
-    InvalidOperation(String),
-    /// No mapping to sn_messages::Error could be found. Either we need a new error there, or we need to handle or convert this error before sending it as a message
-    #[error("No mapping to sn_messages error is set up for this NodeError {0}")]
-    NoErrorMapping(String),
     /// Configuration error.
     #[error("Configuration error: {0}")]
     Configuration(String),
-    /// Configuration error.
+    /// Invalid node authority for a query response.
     #[error("Invalid node authority received for a QueryResponse message")]
     InvalidQueryResponseAuthority,
     /// Sled error.
@@ -150,30 +130,25 @@ pub enum Error {
 
 impl From<qp2p::ClientEndpointError> for Error {
     fn from(error: qp2p::ClientEndpointError) -> Self {
-        Self::CannotConnectEndpoint {
-            err: match error {
-                qp2p::ClientEndpointError::Config(error) => qp2p::EndpointError::Config(error),
-                qp2p::ClientEndpointError::Socket(error) => qp2p::EndpointError::Socket(error),
-            },
-        }
+        let endpoint_err = match error {
+            qp2p::ClientEndpointError::Config(error) => qp2p::EndpointError::Config(error),
+            qp2p::ClientEndpointError::Socket(error) => qp2p::EndpointError::Socket(error),
+        };
+
+        Self::CannotConnectEndpoint(endpoint_err)
     }
 }
 
 impl From<qp2p::SendError> for Error {
     fn from(error: qp2p::SendError) -> Self {
-        Self::AddressNotReachable {
-            err: qp2p::RpcError::Send(error),
-        }
+        Self::AddressNotReachable(qp2p::RpcError::Send(error))
     }
 }
 
 pub(crate) fn convert_to_error_message(error: Error) -> ErrorMessage {
     match error {
-        Error::InvalidOperation(msg) => ErrorMessage::InvalidOperation(msg),
-        // Error::InvalidMessage(_, msg) => ErrorMessage::InvalidOperation(msg),
         Error::InvalidOwner(key) => ErrorMessage::InvalidOwner(key),
         Error::NoSuchData(address) => ErrorMessage::DataNotFound(address),
-        Error::TempDirCreationFailed(_) => ErrorMessage::FailedToWriteFile,
         Error::DataExists => ErrorMessage::DataExists,
         Error::NetworkData(error) => convert_dt_error_to_error_message(error),
         other => {
